package com.supervision.ai.service.hub.aop;
import cn.hutool.core.util.StrUtil;
import com.supervision.ai.service.hub.domain.AuditLog;
import jakarta.servlet.http.HttpServletRequest;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;

import java.io.Serializable;
import java.time.LocalDateTime;
import java.time.temporal.ChronoUnit;

@Slf4j
@Data
public class AuditLogDTO implements Serializable {
    /**
     * 主键id
     */
    private String id;

    /**
     * 记录类型：0-正常操作记录；1-异常记录
     */
    private String recordType;

    /**
     * 用户id
     */
    private String userId;

    private String appName;

    /**
     * 操作人ip地址
     */
    private String ip;

    /**
     * 请求类型 GET POST PUT DELETE
     */
    private String method;

    /**
     * url地址
     */
    private String url;

    /**
     * 请求参数
     */
    private String requestParams;

    /**
     * 响应结果
     */
    private String response;

    /**
     * 异常描述
     */
    private String exceptionDesc;

    /**
     * 创建时间
     */
    private LocalDateTime createTime;

    /**
     * 创建人
     */
    private String createUserId;

    /**
     * 更新时间
     */
    private LocalDateTime updateTime;

    /**
     * 更新用户id
     */
    private String updateUserId;

    private LocalDateTime startTime;

    private LocalDateTime endTime;


    public AuditLogDTO() {
    }

    public AuditLogDTO(HttpServletRequest request) {
        Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
        this.appName = authentication.getName();
        this.url = request.getRequestURI();
        this.method = request.getMethod();
        if (StrUtil.isNotBlank(request.getHeader("X-Real-IP"))){
            this.ip = request.getHeader("X-Real-IP");
        }else {
            this.ip = request.getRemoteAddr();
        }
        this.startTime = LocalDateTime.now();
    }

    public AuditLogDTO(String recordType, String userId, String appName, String ip) {
        this.recordType = recordType;
        this.userId = userId;
        this.appName = appName;
        this.ip = ip;
    }

    public AuditLog toAuditLog(){
    	AuditLog auditLog = new AuditLog();
        auditLog.setId(id);
        auditLog.setRecordType(recordType);
        auditLog.setUserId(userId);
        auditLog.setAppName(appName);
        auditLog.setIp(ip);
        auditLog.setMethod(method);
        auditLog.setUrl(url);
        auditLog.setRequestParams(requestParams);
        auditLog.setCostTime((int)(this.evaluateCostTime()));
        auditLog.setResponse(response);
        auditLog.setExceptionDesc(exceptionDesc);
        auditLog.setCreateTime(createTime);
        auditLog.setCreateUserId(createUserId);
        auditLog.setUpdateTime(updateTime);
        auditLog.setUpdateUserId(updateUserId);
        return auditLog;
    }

    public long evaluateCostTime() {
        if (null == this.startTime || null == this.endTime){
            return 0;
        }
        return ChronoUnit.MILLIS.between(this.startTime, this.endTime);
    }


}
