package com.supervision.ai.service.hub.config;

import io.minio.BucketExistsArgs;
import io.minio.MakeBucketArgs;
import io.minio.MinioClient;
import io.minio.errors.*;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import java.io.IOException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;

/**
 * Endpoint	对象存储服务的URL
 * Access Key	Access key就像用户ID，可以唯一标识你的账户。
 * Secret Key	Secret key是你账户的密码。
 *
 * @author qmy
 * @since 1.0.0
 */
@Slf4j
@Configuration
public class MinioClientConfig {

    @Value("${minio.endpoint}")
    private String endpoint;

    @Value("${minio.accessKey}")
    private String accessKey;

    @Value("${minio.secretKey}")
    private String secretKey;

    @Value("${minio.bucketName}")
    private String bucketName;

    @Bean
    @Primary
    public MinioClient minioClient() throws ServerException, InsufficientDataException, ErrorResponseException,
            IOException, NoSuchAlgorithmException, InvalidKeyException, InvalidResponseException,
            XmlParserException, InternalException {
        MinioClient client = MinioClient.builder()
                .endpoint(endpoint)
                .credentials(accessKey, secretKey)
                .build();

        // 判断bucket是否存在，如果不存在则创建
        if (!client.bucketExists(BucketExistsArgs.builder().bucket(bucketName).build())) {
            log.info("未找到bucket:{},自动创建...", bucketName);
            client.makeBucket(MakeBucketArgs.builder().bucket(bucketName).build());
        } else {
            log.info("bucket:{}已存在...", bucketName);
        }
        return client;
    }

}

