package com.supervision.ai.service.hub.constant;

import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.NumberUtil;
import lombok.Getter;

@Getter
public enum ComfyuiParamTypeEnum {
    // 整数
    INTEGER(0,"整数", Integer.class) {
        @Override
        public Object coverType(Object value) {
            if (null == value){
                return null;
            }
            if (value instanceof Integer){
                return value;
            }
            Assert.isTrue(NumberUtil.isNumber(value.toString()),"参数类型错误");
            return NumberUtil.parseInt(value.toString());
        }
    },
    // 浮点型
    FLOAT(1,"浮点型", Float.class) {
        @Override
        public Object coverType(Object value) {
            if (null == value){
                return null;
            }
            if (value instanceof Float){
                return value;
            }
            Assert.isTrue(NumberUtil.isNumber(value.toString()),"参数类型错误");
            return NumberUtil.parseFloat(value.toString());
        }
    },
    // 字符串
    STRING(2,"字符串",String.class) {
        @Override
        public Object coverType(Object value) {
            if (null == value){
                return null;
            }
            if (value instanceof String){
                return value;
            }
            return value.toString();
        }
    },
    // 布尔值
    BOOLEAN(3,"布尔值",Boolean.class) {
        @Override
        public Object coverType(Object value) {
            if (null == value){
                return null;
            }
            if (value instanceof Boolean){
                return value;
            }
            Assert.isTrue(false,"参数类型错误");
            return null;
        }
    };

    private final int code;
    private final String desc;

    private final Class<?> type;

    ComfyuiParamTypeEnum(int code, String desc,Class<?> type) {
        this.code = code;
        this.desc = desc;
        this.type = type;
    }


    public static ComfyuiParamTypeEnum getByCode(int code){
        for (ComfyuiParamTypeEnum value : ComfyuiParamTypeEnum.values()) {
            if (value.getCode() == code){
                return value;
            }
        }
        return null;
    }

    public abstract Object coverType(Object value);
}
