package com.supervision.ai.service.hub.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.ai.service.hub.dto.common.R;
import com.supervision.ai.service.hub.dto.sys.AppDTO;
import com.supervision.ai.service.hub.service.SysAppService;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

/**
 * 应用管理
 */
@RestController
@RequestMapping("/app")
@RequiredArgsConstructor
public class ApplicationController {

    private final SysAppService sysAppService;

    /**
     * 保存应用信息
     * @param appDTO
     * @return
     */
    @PostMapping("/save")
    public R<String> saveApp(@RequestBody AppDTO appDTO) {
        String id =  sysAppService.saveApp(appDTO);
        return R.ok(id);
    }

    /**
     * 更新应用信息
     * @param appDTO
     * @return
     */
    @PostMapping("/update")
    public R<Boolean> updateApp(@RequestBody AppDTO appDTO) {
        Boolean success = sysAppService.updateApp(appDTO);
        return R.ok(success);
    }

    /**
     * 删除应用信息
     * @param appDTO
     * @return
     */
    @PostMapping("/delete")
    public R<Boolean> deleteApp(@RequestBody AppDTO appDTO) {
        Boolean success = sysAppService.deleteApp(appDTO);
        return R.ok(success);
    }

    /**
     * 分页查询应用信息
     * @param appName
     * @param page
     * @param pageSize
     * @return
     */
    @GetMapping("/pageList")
    public R<IPage<AppDTO>> pageList(@RequestParam(name = "appName", required = false) String appName,
                                     @RequestParam (name = "page", required = false,defaultValue = "1") Integer page,
                                     @RequestParam (name = "pageSize", required = false,defaultValue = "10") Integer pageSize) {
        IPage<AppDTO> appList = sysAppService.pageList(appName, page, pageSize);
        return R.ok(appList);
    }

    /**
     * 根据id查询应用信息
     * @param id
     * @return
     */
    @PostMapping("/queryById")
    public R<AppDTO> queryById(@RequestParam String id) {
        AppDTO app = sysAppService.queryById(id);
        return R.ok(app);
    }
}

