package com.supervision.ai.service.hub.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.ai.service.hub.dto.common.R;
import com.supervision.ai.service.hub.dto.sys.FileDTO;
import com.supervision.ai.service.hub.service.SysFileService;
import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

/**
 * 文件管理
 */
@RestController
@RequestMapping("/file")
@RequiredArgsConstructor
public class FileController {

    private final SysFileService fileService;

    /**
     * 上传文件
     * @param file 文件
     * @return
     */
    @PostMapping("/upload")
    public R<String> upload(@RequestPart("file") MultipartFile file) {

        String fileId = fileService.upload(file);
        return R.ok(fileId);
    }


    /**
     * 分页查询文件列表
     * @param fileName
     * @param fileType
     * @param page
     * @param pageSize
     * @return
     */
    @PostMapping("/pageList")
    public R<IPage<FileDTO>> pageList(@RequestParam(name = "fileName", required = false) String fileName,
                                      @RequestParam(name = "fileType", required = false) String fileType,
                                      @RequestParam (name = "page", required = false,defaultValue = "1") Integer page,
                                      @RequestParam (name = "pageSize", required = false,defaultValue = "10") Integer pageSize) {
        IPage<FileDTO> list = fileService.pageList(fileName, fileType, page, pageSize);
        return R.ok(list);
    }

    /**
     * 查询文件详情
     * @param id 文件ID
     * @return
     */
    @PostMapping("/queryById")
    public R<FileDTO> queryById(@RequestParam(name = "id") String id) {
        FileDTO file = fileService.queryById(id);
        return R.ok(file);
    }

    /**
     * 下载文件
     * @param fileId
     * @param response
     */
    @GetMapping("/downLoad")
    public void downLoad(@RequestParam("fileId") String fileId, HttpServletResponse response) {
        fileService.downLoad(fileId,response);
    }
}
