package com.supervision.ai.service.hub.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.ai.service.hub.dto.comfyui.ComfyUIPromptDTO;
import com.supervision.ai.service.hub.dto.common.R;
import com.supervision.ai.service.hub.service.ComfyUIService;
import com.supervision.ai.service.hub.vo.comfyui.RunPromptReqVo;
import com.supervision.ai.service.hub.vo.comfyui.TaskResultResVo;
import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

@RestController
@RequestMapping("/model")
@RequiredArgsConstructor
public class ModelController {

    private final ComfyUIService comfyUIService;


    /**
     * 保存模型
     * @param comfyUIPromptDTO 模型信息
     * @return
     */
    @PostMapping("/save")
    public R<String> saveModel(@RequestBody ComfyUIPromptDTO comfyUIPromptDTO) {
        String modelId = comfyUIService.saveModel(comfyUIPromptDTO);
        return R.ok(modelId);
    }

    /**
     * 更新模型
     * @param comfyUIPromptDTO 模型信息
     * @return
     */
    @PostMapping("/update")
    public R<Boolean> updateModel(@RequestBody ComfyUIPromptDTO comfyUIPromptDTO) {
        Boolean success = comfyUIService.updateModel(comfyUIPromptDTO);
        return R.ok(success);
    }

    @PostMapping("/delete")
    public R<Boolean> deleteModel(@RequestBody ComfyUIPromptDTO comfyUIPromptDTO) {
        Boolean success = comfyUIService.deleteModel(comfyUIPromptDTO);
        return R.ok(success);
    }

    @GetMapping("/queryById")
    public R<ComfyUIPromptDTO> queryById(@RequestParam(name = "id") String id) {
        ComfyUIPromptDTO comfyUIPromptDTO = comfyUIService.queryById(id);
        return R.ok(comfyUIPromptDTO);
    }

    @PostMapping("/pageList")
    public R<IPage<ComfyUIPromptDTO>> pageList(@RequestParam(name = "promptName", required = false) String promptName,
                                               @RequestParam(name = "promptType", required = false) String promptType,
                                               @RequestParam(name = "page", defaultValue = "1") Integer page,
                                               @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize) {
        IPage<ComfyUIPromptDTO> pageList = comfyUIService.pageList(promptName, promptType, page, pageSize);
        return R.ok(pageList);
    }

    /**
     * 执行任务
     * @param runPromptReqVo prompt信息
     * @return
     */
    @PostMapping("/executeTask")
    public R<String> executeTask(@RequestBody RunPromptReqVo runPromptReqVo) {

        String taskId = comfyUIService.executeTask(runPromptReqVo);
        return R.ok(taskId);
    }

    @GetMapping("/getTaskById")
    public R<TaskResultResVo> getTaskById(@RequestParam(name = "taskId", required = false) String taskId) {
        TaskResultResVo taskResultResVos = comfyUIService.getTaskById(taskId);
        return R.ok(taskResultResVos);
    }

    @GetMapping("/queryTaskPageList")
    public R<IPage<TaskResultResVo>> queryTaskPageList(@RequestParam(name = "taskId", required = false) String taskId) {
        IPage<TaskResultResVo> taskResultResVos = comfyUIService.queryHistory(taskId);
        return R.ok(taskResultResVos);
    }

    @PostMapping("/uploadImage")
    public R<String> uploadImage(@RequestParam("file") MultipartFile file) throws Exception {
        String imageId = comfyUIService.uploadImage(file);
        return R.ok(imageId);
    }

    @GetMapping("/downloadView")
    public void downloadView(@RequestParam("fileName") String fileName, HttpServletResponse response) throws Exception {
        comfyUIService.downloadView(fileName, response);
    }
}
