package com.supervision.ai.service.hub.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.ai.service.hub.dto.sys.PermissionDTO;
import com.supervision.ai.service.hub.dto.common.R;
import com.supervision.ai.service.hub.service.PermissionService;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 权限管理
 */
@RestController
@RequestMapping("/permission")
@RequiredArgsConstructor
public class PermissionController {

    private final PermissionService permissionService;

    /**
     * 保存权限
     * @param permissionDTO 权限信息
     * @return 权限ID
     */
    @PostMapping("/save")
    public R<String> savePermission(@RequestBody PermissionDTO permissionDTO) {

        String permissionId = permissionService.savePermission(permissionDTO);
        return R.ok(permissionId);
    }


    /**
     * 更新权限
     * @param permissionDTO
     * @return
     */
    @PostMapping("/update")
    public R<Boolean> updatePermission(@RequestBody PermissionDTO permissionDTO) {

        Boolean success = permissionService.updatePermission(permissionDTO);
        return R.ok(success);
    }

    /**
     * 删除权限
     * @param permissionDTO
     * @return
     */
    @PostMapping("/delete")
    public R<Boolean> deletePermission(@RequestBody PermissionDTO permissionDTO) {

        Boolean success = permissionService.deletePermission(permissionDTO.getId());
        return R.ok(success);
    }

    /**
     * 查询权限
     * @param type 权限类型
     * @return 返回一个树形结构
     */
    @GetMapping("/query")
    public R<List<PermissionDTO>> queryPermission(@RequestParam (name = "type", required = false) String type) {

        List<PermissionDTO> list = permissionService.queryPermission(type);
        return R.ok(list);
    }

    /**
     * 分页查询权限
     * @param permissionName
     * @param page
     * @param pageSize
     * @return
     */
    @PostMapping("/pageList")
    public R<IPage<PermissionDTO>> pageList(@RequestParam (name = "permissionName", required = false) String permissionName,
                                            @RequestParam (name = "page", required = false) Integer page,
                                            @RequestParam(name = "pageSize", required = false) Integer pageSize) {

        IPage<PermissionDTO> list = permissionService.pageList(permissionName, page, pageSize);
        return R.ok(list);
    }

    /**
     * 根据ID查询权限
     * @param id
     * @return
     */
    @GetMapping("/queryById")
    public R<PermissionDTO> queryById(@RequestParam(name = "id") String id) {

        PermissionDTO permissionDTO = permissionService.queryById(id);
        return R.ok(permissionDTO);
    }
}
