package com.supervision.ai.service.hub.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.ai.service.hub.dto.common.R;
import com.supervision.ai.service.hub.dto.sys.SysRoleDTO;
import com.supervision.ai.service.hub.service.SysRoleService;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

/**
 * 角色管理
 */
@RestController
@RequestMapping("/role")
@RequiredArgsConstructor
public class RoleController {

    private final SysRoleService roleService;

    /**
     * 保存角色信息
     * @param roleDTO 权限信息
     * @return 权限ID
     */
    @PostMapping("/save")
    public R<String> saveRole(@RequestBody SysRoleDTO roleDTO) {

        String roleId = roleService.saveRole(roleDTO);
        return R.ok(roleId);
    }


    /**
     * 更新角色
     * @param roleDTO
     * @return
     */
    @PostMapping("/update")
    public R<Boolean> updateRole(@RequestBody SysRoleDTO roleDTO) {

        Boolean success = roleService.updateRole(roleDTO);
        return R.ok(success);
    }

    /**
     * 删除角色
     * @param roleDTO
     * @return
     */
    @PostMapping("/delete")
    public R<Boolean> deleteRole(@RequestBody SysRoleDTO roleDTO) {

        Boolean success = roleService.deleteRole(roleDTO.getId());
        return R.ok(success);
    }


    /**
     * 分页查询角色
     * @param roleName
     * @param page
     * @param pageSize
     * @return
     */
    @PostMapping("/pageList")
    public R<IPage<SysRoleDTO>> pageList(@RequestParam (name = "roleName", required = false) String roleName,
                                         @RequestParam (name = "page", defaultValue = "1", required = false) Integer page,
                                         @RequestParam(name = "pageSize",defaultValue = "10", required = false) Integer pageSize ) {

        IPage<SysRoleDTO> list = roleService.pageList(roleName, page, pageSize);
        return R.ok(list);
    }

    /**
     * 根据id查询角色
     * @return
     */
    @GetMapping("/queryById")
    public R<SysRoleDTO> queryById(@RequestParam(name = "id") String id) {

        SysRoleDTO sysRoleDTO = roleService.queryById(id);
        return R.ok(sysRoleDTO);
    }
}
