package com.supervision.ai.service.hub.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.ai.service.hub.dto.common.R;
import com.supervision.ai.service.hub.dto.comfyui.TaskDTO;
import com.supervision.ai.service.hub.service.TaskService;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 *
 * 任务管理
 */
@RestController
@RequestMapping("/task")
@RequiredArgsConstructor
public class TaskController {

    private final TaskService taskService;

    /**
     * 分页查询任务信息
     * @param taskName
     * @param taskType
     * @param status
     * @param page
     * @param pageSize
     * @return
     */
    @GetMapping("/pageList")
    public R<IPage<TaskDTO>> pageList(@RequestParam(name = "taskName", required = false) String taskName,
                                        @RequestParam(name = "taskType", required = false) String taskType,
                                        @RequestParam(name = "status", required = false) String status,
                                        @RequestParam(name = "page", defaultValue = "1") Integer page,
                                        @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize) {
        IPage<TaskDTO> pageList = taskService.pageList(taskName, taskType, status, page, pageSize);
        return R.ok(pageList);
    }



    /**
     * 取消（终止）任务
     * @param taskIds
     * @return
     */
    @PostMapping("/cancel")
    public R<Boolean> cancelTask(List<String> taskIds) {
        Boolean success = taskService.cancelTask(taskIds);
        return R.ok(success);
    }

    /**
     * 重试任务
     * @param taskIds
     * @return
     */
    @PostMapping("/retry")
    public R<Boolean> retryTask(List<String> taskIds) {
        Boolean success = taskService.retryTask(taskIds);
        return R.ok(success);
    }
}
