package com.supervision.ai.service.hub.controller;

import cn.hutool.core.lang.Assert;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.ai.service.hub.domain.SysUser;
import com.supervision.ai.service.hub.dto.common.R;
import com.supervision.ai.service.hub.dto.sys.UserDTO;
import com.supervision.ai.service.hub.service.SysUserService;
import lombok.RequiredArgsConstructor;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 用户控制器，用于处理用户相关接口
 */
@RestController
@RequestMapping("/user")
@RequiredArgsConstructor
public class UserController {

    private final SysUserService sysUserService;

    /**
     * 查看当前用户详情接口
     *
     * @return 当前登录用户的详细信息，如果用户不存在，则返回 404
     */
    @GetMapping("/me")
    public R<SysUser> getCurrentUserDetails() {
        Authentication authentication = SecurityContextHolder.getContext().getAuthentication();
        String username = authentication.getName();
        SysUser user = sysUserService.getByUsername(username);
        Assert.notNull(user, "用户不存在");
        return R.ok(user);
    }

    /**
     * 保存用户信息
     * @param user 用户信息
     * @return
     */
    @PostMapping("/save")
    public R<String> saveUser(UserDTO user) {
        String userId = sysUserService.saveUser(user);
        return R.ok(userId);
    }

    /**
     * 更新用户信息
     * @param user 用户信息
     * @return
     */
    @PostMapping("/update")
    public R<Boolean> updateUser(UserDTO user) {
        Boolean success = sysUserService.updateUser(user);
        return R.ok(success);
    }

    /**
     * 删除用户
     * @param user 用户信息
     * @return
     */
    @PostMapping("/delete")
    public R<Boolean> deleteUser(UserDTO user) {
        Boolean success = sysUserService.deleteUser(user.getId());
        return R.ok(success);
    }

    /**
     * 查询用户列表
     * @param userName 用户名
     * @param page 页码
     * @param pageSize 每页数量
     * @return 用户列表
     */
    @GetMapping("/pageList")
    public R<IPage<UserDTO>> queryList(@RequestParam(name = "userName", required = false) String userName,
                                       @RequestParam (name = "page", required = false,defaultValue = "1") Integer page,
                                       @RequestParam (name = "pageSize", required = false,defaultValue = "10") Integer pageSize) {
        IPage<UserDTO> list = sysUserService.pageList(userName, page, pageSize);
        return R.ok(list);
    }

    /**
     * 根据ID查询用户
     * @param id 用户ID
     * @return 用户信息
     */
    @GetMapping("/queryById")
    public R<UserDTO> queryById(@RequestParam(name = "id") String id) {
        UserDTO userDTO = sysUserService.queryById(id);
        return R.ok(userDTO);
    }
}
