package com.supervision.ai.service.hub.dto.comfyui;

import cn.hutool.core.collection.CollUtil;
import com.alibaba.fastjson.JSONObject;
import com.supervision.ai.service.hub.domain.ComfyuiTask;
import com.supervision.ai.service.hub.domain.ComfyuiTaskParam;
import com.supervision.ai.service.hub.domain.ComfyuiTaskResult;
import lombok.Data;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

@Data
public class TaskDTO {

    private String id;

    /**
     * 提示词id
     */
    private String promptId;

    /**
     * comfyui平台任务id
     */
    private String comfyuiTaskId;


    private String comfyuiServer;;

    /**
     * 创建人id
     */
    private String userId;

    /**
     * 应用id
     */
    private String appId;

    /**
     * 运行状态 0未开始、1进行中、2成功、3失败
     */
    private String runStatus;

    /**
     * 开始运行时间
     */
    private LocalDateTime runStartTime;

    /**
     * 运行结束时间
     */
    private LocalDateTime runEndTime;

    /**
     * webhook url
     */
    private String webHook;

    private JSONObject prompt;


    private List<ComfyuiTaskParam> params = new ArrayList<>();


    private List<ComfyUITaskResult> results = new ArrayList<>();


    /**
     * 创建时间
     */
    private LocalDateTime createTime;


    public TaskDTO() {
    }

    public TaskDTO(ComfyuiTask task, List<ComfyuiTaskParam> params, List<ComfyuiTaskResult> taskResults) {
        this.id = task.getId();
        this.promptId = task.getPromptId();
        this.comfyuiTaskId = task.getComfyuiTaskId();
        this.comfyuiServer = task.getComfyuiServer();
        this.userId = task.getUserId();
        this.appId = task.getAppId();
        this.runStatus = task.getRunStatus();
        this.runStartTime = task.getRunStartTime();
        this.runEndTime = task.getRunEndTime();
        this.webHook = task.getWebHook();
        this.prompt = task.getPrompt();
        this.createTime = task.getCreateTime();
        this.params = params;
        if (CollUtil.isNotEmpty(taskResults)){
            for (ComfyuiTaskResult taskResult : taskResults) {
                ComfyUITaskResult result = new ComfyUITaskResult();
                result.setId(taskResult.getId());
                result.setTaskId(taskResult.getTaskId());
                result.setFileId(taskResult.getResultFileId());
                this.results.add(result);
            }
        }
    }
}
