package com.supervision.ai.service.hub.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.supervision.ai.service.hub.domain.ComfyuiPromptParam;
import com.supervision.ai.service.hub.service.ComfyUIPromptParamService;
import com.supervision.ai.service.hub.mapper.ComfyuiPromptParamMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;

/**
* @author Administrator
* @description 针对表【comfyui_prompt_param】的数据库操作Service实现
* @createDate 2025-03-31 17:49:56
*/
@Slf4j
@Service
public class ComfyUIPromptParamServiceImpl extends ServiceImpl<ComfyuiPromptParamMapper, ComfyuiPromptParam>
        implements ComfyUIPromptParamService {


    @Override
    public boolean requiredCheck(Map<String, Object> params, String promptId) {
        Assert.notEmpty(promptId, "promptId不能为空");
        List<ComfyuiPromptParam> list = this.lambdaQuery()
                .eq(ComfyuiPromptParam::getPromptId, promptId).eq(ComfyuiPromptParam::getRequired, true).list();

        return requiredCheck(params, list);
    }

    @Override
    public boolean requiredCheck(Map<String, Object> params, List<ComfyuiPromptParam> promptParamList) {
        if (CollUtil.isEmpty(promptParamList)) {
            return true;
        }
        if (CollUtil.isEmpty(params)){
            return false;
        }
        for (ComfyuiPromptParam comfyuiPromptParam : promptParamList) {
            Object value = params.get(comfyuiPromptParam.getParamKey());
            if (null == value || "".equals(value)) {
                log.error("参数{}为必填项，请检查",comfyuiPromptParam.getParamKey());
                return false;
            }
        }
        return true;
    }

    @Override
    public List<ComfyuiPromptParam> listByPromptId(String promptId) {
        return super.lambdaQuery().eq(ComfyuiPromptParam::getPromptId, promptId).list();
    }

    @Override
    public ComfyuiPromptParam selectPromptParam(String paramKey, List<ComfyuiPromptParam> promptParamList) {
        if (CollUtil.isEmpty(promptParamList)){
            return null;
        }
        for (ComfyuiPromptParam comfyuiPromptParam : promptParamList) {
            if (StrUtil.equals(comfyuiPromptParam.getParamKey(), paramKey)){
                return comfyuiPromptParam;
            }
        }
        return null;
    }

}




