package com.supervision.ai.service.hub.service.impl;

import cn.hutool.core.bean.BeanPath;
import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.lang.Assert;
import cn.hutool.core.util.StrUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.supervision.ai.service.hub.constant.ComfyuiParamTypeEnum;
import com.supervision.ai.service.hub.domain.ComfyuiPrompt;
import com.supervision.ai.service.hub.domain.ComfyuiPromptParam;
import com.supervision.ai.service.hub.dto.comfyui.*;
import com.supervision.ai.service.hub.service.ComfyUIApiService;
import com.supervision.ai.service.hub.service.ComfyUIService;
import com.supervision.ai.service.hub.service.ComfyUIPromptParamService;
import com.supervision.ai.service.hub.service.ComfyUIPromptService;
import com.supervision.ai.service.hub.vo.comfyui.RunPromptReqVo;
import com.supervision.ai.service.hub.vo.comfyui.TaskResultResVo;
import jakarta.servlet.ServletOutputStream;
import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Slf4j
@Service
@RequiredArgsConstructor
public class ComfyUIServiceImpl implements ComfyUIService {

    private final ComfyUIApiService comfyUIApiService;

    private final ComfyUIPromptService comfyuiPromptService;

    private final ComfyUIPromptParamService comfyuiPromptParamService;


    @Override
    public String executeTask(RunPromptReqVo runPromptReqVo) {
        Assert.notEmpty(runPromptReqVo.getPromptId(),"promptId不能为空");
        boolean exist = comfyuiPromptService.promptExist(runPromptReqVo.getPromptId());
        Assert.isTrue(exist,"promptId不存在");

        // 必填参数校验
        List<ComfyuiPromptParam> promptParams = comfyuiPromptParamService.listByPromptId(runPromptReqVo.getPromptId());
        List<ComfyuiPromptParam> requiredParams = promptParams.stream().filter(ComfyuiPromptParam::getRequired).toList();
        boolean checkPass = comfyuiPromptParamService.requiredCheck(runPromptReqVo.getParams(), requiredParams);
        Assert.isTrue(checkPass,
                "必填参数"+requiredParams.stream().map(ComfyuiPromptParam::getParamKey).collect(Collectors.joining(","))+"不能为空");

        ComfyuiPrompt comfyuiPrompt = comfyuiPromptService.getById(runPromptReqVo.getPromptId());
        Assert.notNull(comfyuiPrompt.getPrompt(), "prompt不能为空");

        // 设置参数
        JSONObject prompt = comfyuiPrompt.getPrompt();
        Map<String, Object> params = runPromptReqVo.getParams();
        for (Map.Entry<String, Object> entry : params.entrySet()) {
            if (null != entry.getValue()){
                ComfyuiPromptParam comfyuiPromptParam = comfyuiPromptParamService.selectPromptParam(entry.getKey(), promptParams);
                if (null == comfyuiPromptParam){
                    continue;
                }
                ComfyuiParamTypeEnum comfyuiParamTypeEnum = ComfyuiParamTypeEnum.getByCode(comfyuiPromptParam.getParamType());
                Assert.notNull(comfyuiParamTypeEnum,"不支持的数据类型");
                Object value = comfyuiParamTypeEnum.coverType(entry.getValue());
                log.info("设置参数key：{},参数value:{}", entry.getKey(), value);
                BeanPath.create(entry.getKey()).set(prompt, value);
            }
        }
        // 运行提示词
        PromptRunDTO promptRunDTO = comfyUIApiService.runPrompt(prompt);
        Map<String, Object> error = promptRunDTO.getError();
        if (CollUtil.isNotEmpty(error)){
            String errorMessage = (String) error.get("message");
            Assert.isTrue(StrUtil.isNotEmpty(errorMessage),errorMessage);
        }
        return promptRunDTO.getPrompt_id();
    }

    @Override
    public IPage<TaskResultResVo> queryHistory(String promptId) {
        Map<String, Object> history = comfyUIApiService.queryHistory(promptId);
        if (CollUtil.isEmpty(history)){
            return null;
        }
        List<TaskResultResVo> resultResVos = new ArrayList<>();
        for (Map.Entry<String, Object> entry : history.entrySet()) {
            TaskResultResVo taskResultResVo = new TaskResultResVo();
            Object value = entry.getValue();
            taskResultResVo.setModelId(entry.getKey());
            if (null != value){
                Map<String, Object> status = (Map<String, Object>) ((Map<String, Object>) value).get("status");
                Boolean completed = (Boolean) status.get("completed");
                if (completed){
                    Map<String, Object> outputs = (Map<String, Object>) ((Map<String, Object>) value).get("outputs");
                    if (CollUtil.isNotEmpty(outputs)){
                        for (Map.Entry<String, Object> outputEntry : outputs.entrySet()) {
                            Map<String,Object> outputEntryValue = (Map<String, Object>) outputEntry.getValue();
                            List<Map<String,Object>> images = (List<Map<String, Object>>) outputEntryValue.get("images");
                            taskResultResVo.setOutputImages(images.stream().map(image -> (String)(image.get("filename"))).collect(Collectors.toList()));
                        }
                    }
                }
            }
            resultResVos.add(taskResultResVo);
        }
        return null;
    }

    @Override
    public boolean taskIsCompleted(Map<String, Object> result){
        if (CollUtil.isEmpty(result)){
            return false;
        }
        Map<String, Object> status = (Map<String, Object>) ((Map<String, Object>) result).get("status");
        return  (Boolean) status.get("completed");
    }

    @Override
    public List<String> getImageList(Map<String, Object> result){
        List<String> imageList = new ArrayList<>();
        if (CollUtil.isNotEmpty(result)){
            Map<String, Object> outputs = (Map<String, Object>) result.get("outputs");
            if (CollUtil.isNotEmpty(outputs)){
                for (Map.Entry<String, Object> outputEntry : outputs.entrySet()) {
                    Map<String,Object> outputEntryValue = (Map<String, Object>) outputEntry.getValue();
                    List<Map<String,Object>> images = (List<Map<String, Object>>) outputEntryValue.get("images");
                    imageList = images.stream().map(image -> (String)(image.get("filename"))).collect(Collectors.toList());
                }
            }
        }
        return imageList;
    }

    @Override
    public String uploadImage(MultipartFile file) throws IOException {
        String filename = file.getOriginalFilename();
        byte[] bytes = file.getBytes();
        ImageUploadDTO imageUploadDTO = comfyUIApiService.uploadImage(bytes, filename);
        if (StrUtil.isNotEmpty(imageUploadDTO.getSubfolder())){
            return imageUploadDTO.getSubfolder() + "/" + imageUploadDTO.getName();
        }
        return imageUploadDTO.getName();
    }

    @Override
    public void downloadView(String imageId, HttpServletResponse response) throws IOException {
        Assert.notEmpty(imageId,"imageId不能为空");
        ResourceViewDTO resourceViewDTO = comfyUIApiService.downloadView(imageId);
        response.setContentType(resourceViewDTO.getContentType());
        response.setHeader("Content-Disposition", "attachment; filename=" + resourceViewDTO.getFileName());
        try (ServletOutputStream outputStream = response.getOutputStream()){
            outputStream.write(resourceViewDTO.getContent());
        }
    }

    @Override
    public String saveModel(ComfyUIPromptDTO comfyUIPromptDTO) {
        return null;
    }

    @Override
    public Boolean updateModel(ComfyUIPromptDTO comfyUIPromptDTO) {
        return null;
    }

    @Override
    public Boolean deleteModel(ComfyUIPromptDTO comfyUIPromptDTO) {
        return null;
    }

    @Override
    public ComfyUIPromptDTO queryById(String id) {
        return null;
    }

    @Override
    public IPage<ComfyUIPromptDTO> pageList(String promptName, String promptType, Integer page, Integer pageSize) {
        return null;
    }

    @Override
    public TaskResultResVo getTaskById(String taskId) {
        return null;
    }
}
