package com.supervision.ai.service.hub.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.supervision.ai.service.hub.constant.ComfyuiRunStatusEnum;
import com.supervision.ai.service.hub.domain.ComfyuiTask;
import com.supervision.ai.service.hub.domain.ComfyuiTaskParam;
import com.supervision.ai.service.hub.domain.ComfyuiTaskResult;
import com.supervision.ai.service.hub.dto.comfyui.ComfyUITaskResult;
import com.supervision.ai.service.hub.dto.comfyui.TaskDTO;
import com.supervision.ai.service.hub.service.ComfyuiTaskParamService;
import com.supervision.ai.service.hub.service.ComfyuiTaskResultService;
import com.supervision.ai.service.hub.service.ComfyuiTaskService;
import com.supervision.ai.service.hub.mapper.ComfyuiTaskMapper;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
* @author Administrator
* @description 针对表【comfyui_task(comfyui任务表)】的数据库操作Service实现
* @createDate 2025-04-11 15:51:10
*/
@Slf4j
@Service
@RequiredArgsConstructor
public class ComfyuiTaskServiceImpl extends ServiceImpl<ComfyuiTaskMapper, ComfyuiTask>
    implements ComfyuiTaskService{

    private final ComfyuiTaskParamService comfyuiTaskParamService;

    private final ComfyuiTaskResultService comfyuiTaskResultService;
    @Override
    public void updateTaskResult(TaskDTO taskDTO) {

    }

    @Override
    public List<TaskDTO> queryNotStartedTask(int size) {
        if (size == 0){
            return new ArrayList<>();
        }
        List<ComfyuiTask> comfyuiTaskList = this.lambdaQuery()
                .eq(ComfyuiTask::getRunStatus, ComfyuiRunStatusEnum.NOT_STARTED.getStatus())
                .orderByAsc(ComfyuiTask::getCreateTime).last("limit " + size).list();
        if (CollUtil.isEmpty(comfyuiTaskList)){
            return new ArrayList<>();
        }
        List<String> taskIds = comfyuiTaskList.stream().map(ComfyuiTask::getId).distinct().toList();

        Map<String, List<ComfyuiTaskParam>> taskParamMap = comfyuiTaskParamService.listByTaskIds(taskIds)
                .stream().collect(Collectors.groupingBy(ComfyuiTaskParam::getTaskId));
        Map<String, List<ComfyuiTaskResult>> taskResultMap = comfyuiTaskResultService.listByTaskIds(taskIds)
                .stream().collect(Collectors.groupingBy(ComfyuiTaskResult::getTaskId));

        return comfyuiTaskList.stream()
                .map(comfyuiTask->new TaskDTO(comfyuiTask, taskParamMap.get(comfyuiTask.getId()), taskResultMap.get(comfyuiTask.getId())))
                .collect(Collectors.toList());
    }

    @Override
    public void notifyWebhook(TaskDTO taskDTO) {
        if (StrUtil.isEmpty(taskDTO.getWebHook())){
            log.info("notifyWebhook:没有配置webhook地址，taskId:{}",taskDTO.getId());
            return;
        }
        Map<String, Object> boyMap = new HashMap<>();
        boyMap.put("taskId", taskDTO.getId());
        boyMap.put("status",taskDTO.getRunStatus());
        boyMap.put("outputImages", taskDTO.getResults().stream().map(ComfyUITaskResult::getFileId).collect(Collectors.toList()));
        HttpRequest request = HttpUtil.createPost(taskDTO.getWebHook())
                .header("Content-Type", "application/json")
                .body(JSONUtil.toJsonStr(boyMap));
        try (HttpResponse execute = request.execute()){
            if (execute.getStatus() != 200){
                log.error("notifyWebhook:发送webhook失败，taskId:{},status:{},response:{}",taskDTO.getId(),taskDTO.getRunStatus(),execute.body());
            }
        }catch (Exception e){
            log.error("notifyWebhook:发送webhook失败，taskId:{},status:{},error:{}",taskDTO.getId(),taskDTO.getRunStatus(),e.getMessage());
        }
    }
}




