package com.supervision.ai.service.hub.service.impl;

import cn.hutool.core.collection.CollUtil;
import com.supervision.ai.service.hub.dto.comfyui.TaskDTO;
import com.supervision.ai.service.hub.service.ComfyuiTaskService;
import com.supervision.ai.service.hub.service.SchedulingStrategy;
import lombok.extern.slf4j.Slf4j;

import java.util.Comparator;
import java.util.List;
import java.util.concurrent.LinkedBlockingQueue;

@Slf4j
public class FifoSchedulingStrategy implements SchedulingStrategy {

    private final ComfyuiTaskService comfyuiTaskService;

    private final LinkedBlockingQueue<TaskDTO> taskQueue = new LinkedBlockingQueue<>();

    public FifoSchedulingStrategy(ComfyuiTaskService comfyuiTaskService) {
        this.comfyuiTaskService = comfyuiTaskService;
    }

    @Override
    public TaskDTO selectNextTask() {
        if (taskQueue.isEmpty()) {
            List<TaskDTO> taskDTOS = comfyuiTaskService.queryNotStartedTask(10);
            if (CollUtil.isEmpty(taskDTOS)){
                log.info("selectNextTask:未从queryNotStartedTask中获取到可用的元素....");
                return null;
            }
            taskDTOS.sort(Comparator.comparing(TaskDTO::getRunStartTime));
            for (TaskDTO taskDTO : taskDTOS) {
                taskQueue.offer(taskDTO);
            }
        }
        return taskQueue.poll();
    }
}
