package com.supervision.ai.service.hub.service.impl;

import com.supervision.ai.service.hub.domain.SysApp;
import com.supervision.ai.service.hub.domain.SysUser;
import com.supervision.ai.service.hub.service.SysAppService;
import com.supervision.ai.service.hub.service.SysUserService;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.security.authentication.DisabledException;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.userdetails.User;
import org.springframework.security.core.userdetails.UserDetails;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.core.userdetails.UsernameNotFoundException;
import org.springframework.stereotype.Service;

import java.util.Collections;
import java.util.List;

import static com.supervision.ai.service.hub.constant.UserConstant.USER_STATUS_DISABLED;

@Slf4j
@Service
@RequiredArgsConstructor
public class UserDetailsServiceImpl implements UserDetailsService {

    private final SysUserService sysUserService;

    private final SysAppService sysAppService;

    @Override
    public UserDetails loadUserByUsername(String username) throws UsernameNotFoundException {

        // 由于sys_app表数据较少，所以优先从sys_app表中查询
        SysApp sysApp = sysAppService.getByAppName(username);

        // 将查询到的用户信息组装成UserDetails对象
        // **扩展点**：如需加载用户角色权限，可在此处查询 sys_user_role 表关联的角色，并将角色加入 authorities 列表
        List<GrantedAuthority> authorities = Collections.emptyList();
        // 使用Spring Security提供的User对象作为UserDetails返回
        if (null == sysApp){
            SysUser user = sysUserService.getByUsername(username);
            if (user == null) {
                throw new UsernameNotFoundException("用户不存在: " + username);
            }
            if (USER_STATUS_DISABLED.equals(user.getStatus())) {
                throw new DisabledException("用户已被禁用");
            }
            return new User(user.getUserName(), user.getPassword(), authorities);
        }
        return new User(sysApp.getAppName(), sysApp.getPassword(), authorities);
    }
}
